package com.nec.peppa.learning.api;

import com.nec.peppa.learning.entity.RecertRule;
import com.nec.peppa.learning.entity.RecertRuleStatus;
import com.nec.peppa.learning.entity.ResultInfo;
import com.nec.peppa.learning.service.impl.RecertRuleServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.stereotype.Controller;


/**
 * <p>
 * 延续认证规则表 前端控制器
 * </p>
 *
 * @author peppa_learning
 * @since 2020-03-08
 */
@Controller
@RestController
@RequestMapping("/peppa_learning-service")
public class RecertRuleController {
    @Autowired
    private RecertRuleServiceImpl recertRuleService;
    // 两表联查，通过延续认证表的字段查询延续认证状态表
    @GetMapping(value = "/recert-rule")
    public Object selectRecertRuleStatus(@RequestBody RecertRule recertRule){
        ResultInfo resultInfo=new ResultInfo();
        try {
            // 为结果集存储数据
            resultInfo.setData(recertRuleService.selectCertRecertRule(recertRule));
            resultInfo.setMsg("通过延续认证表的字段查询延续认证状态表方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (NumberFormatException e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(0);
            resultInfo.setMsg("通过延续认证表的字段查询延续认证状态表方法出现异常,请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 通过Id查找一条数据
    @GetMapping(value = "/recert-rule/{recertRuleId}")
    public ResultInfo findOneById(@PathVariable("recertRuleId")String recertRuleId){
        ResultInfo resultInfo=new ResultInfo();
        try {
            // 把接收的String类型的字符串转换成long类型
            Long recertRuleIdL=Long.parseLong(recertRuleId);
            // 为结果集存储数据
            resultInfo.setData(recertRuleService.findOneById(recertRuleIdL));
            resultInfo.setMsg("通过Id查找一条数据方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (NumberFormatException e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(null);
            resultInfo.setMsg("通过Id查找一条数据方法出现异常,请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 新增一条数据
    @PostMapping(value = "/recert-rule")
    public ResultInfo insertSelect(@RequestBody RecertRule recertRule){
        ResultInfo resultInfo=new ResultInfo();
        try {
            // 为结果集存储数据
            resultInfo.setData(recertRuleService.insertSelect(recertRule));
            resultInfo.setMsg("新增一条数据方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (NumberFormatException e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(0);
            resultInfo.setMsg("新增一条数据方法出现异常,请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 通过Id删除一条数据
    @DeleteMapping(value = "/recert-rule/{recertRuleId}")
    public ResultInfo deleteById(@PathVariable("recertRuleId") String recertRuleId){
        ResultInfo resultInfo=new ResultInfo();
        try {
            // 把接收的String类型的字符串转换成long类型
            Long recertRuleIdL=Long.parseLong(recertRuleId);
            // 为结果集存储数据
            resultInfo.setData(recertRuleService.deleteById(recertRuleIdL));
            resultInfo.setMsg("通过Id删除数据已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (NumberFormatException e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(0);
            resultInfo.setMsg("通过Id删除数据方法出现异常,请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    /*
     通过Id修改任意字段信息
     @Param recertRule  延续认证规则对象
     @return resultInfo  结果集对象
    */
    @PutMapping(value = "/recert-rule")
    public ResultInfo updateSelectById(@RequestBody RecertRule recertRule){
            ResultInfo resultInfo=new ResultInfo();
            try {
                // 调用方法,返回修改结果
                int result = recertRuleService.updateSelectById(recertRule);
                resultInfo.setData(result);
                resultInfo.setMsg("通过Id修改任意字段信息方法已正常返回结果");
                resultInfo.setFlag(true);
                return resultInfo;
            } catch (Exception e) {
                // 方法报错后的异常处理
                e.printStackTrace();
                // 给结果集赋值为0 修改失败
                resultInfo.setData(0);
                resultInfo.setMsg("通过Id修改任意字段信息方法出现异常，请尽快处理");
                resultInfo.setFlag(false);
                return resultInfo;
            }
    }
}

