package com.nec.peppa.learning.api;
import com.nec.peppa.learning.entity.RecertRuleStatus;
import com.nec.peppa.learning.entity.ResultInfo;
import com.nec.peppa.learning.entity.Rule;
import com.nec.peppa.learning.service.impl.RecertRuleStatusServiceImpl;
import com.nec.peppa.learning.service.impl.RuleServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.springframework.stereotype.Controller;



/**
 * <p>
 * 认证规则表 前端控制器
 * </p>
 *
 * @author peppa_learning
 * @since 2020-03-08
 */
@Controller
@RestController
@RequestMapping("/peppa_learning-service")
public class RuleController {
    @Autowired
    private RuleServiceImpl ruleService;
    // 创建结果集对象
    private ResultInfo resultInfo=new ResultInfo();
    // 查询全部数据
    @GetMapping(value = "/rule")
    public ResultInfo findAll(){
        try {
            resultInfo.setData(ruleService.findAll());
            resultInfo.setMsg("认证规则表查询全部数据的方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (Exception e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(null);
            resultInfo.setMsg("认证规则表查询全部数据的方法出现异常，请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 根据主键查询一条数据
    @GetMapping(value = "/rule/{certRuleId}")
    public ResultInfo findOneById(@PathVariable String certRuleId){
        try {
            // 把接收的字符串类型的主键转换为Long类型
            Long certRuleIdL=Long.parseLong(certRuleId);
            resultInfo.setData(ruleService.findOneById(certRuleIdL));
            resultInfo.setMsg("认证规则表根据主键查询一条数据方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (Exception e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(null);
            resultInfo.setMsg("认证规则表根据主键查询一条数据的方法出现异常，请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 新增一条数据
    @PostMapping(value = "/rule")
    public ResultInfo insert(@RequestBody Rule rule){
        try {
            resultInfo.setData(ruleService.insert(rule));
            resultInfo.setMsg("认证规则表新增一条数据方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (Exception e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(0);
            resultInfo.setMsg("认证规则表新增一条数据的方法出现异常，请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 根据主键删除一条数据
    @DeleteMapping(value = "/rule/{certRuleId}")
    public ResultInfo insert(@PathVariable String certRuleId){
        try {
            // 把接收的字符串类型的主键转换为Long类型
            Long certRuleIdL=Long.parseLong(certRuleId);
            resultInfo.setData(ruleService.delete(certRuleIdL));
            resultInfo.setMsg("认证规则表根据主键删除一条数据的方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (Exception e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(0);
            resultInfo.setMsg("认证规则表根据主键删除一条数据的方法出现异常，请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
    // 根据主键修改一条数据
    @PutMapping(value = "/rule")
    public ResultInfo update(@RequestBody Rule rule){
        try {
            resultInfo.setData(ruleService.update(rule));
            resultInfo.setMsg("认证规则表根据主键修改一条数据的方法已正常返回结果");
            resultInfo.setFlag(true);
            return resultInfo;
        } catch (Exception e) {
            // 异常处理
            e.printStackTrace();
            resultInfo.setData(0);
            resultInfo.setMsg("认证规则表根据主键修改一条数据的方法出现异常，请尽快处理");
            resultInfo.setFlag(false);
            return resultInfo;
        }
    }
}

